# Script Locked by: CiscoOfficial
# Script Version: 2.0.0
# Script Name: 
# Script Lock Date: Thu Feb  1 22:34:49 2001
# May 24, 2001, Jinsong Liu
#
# Updated: 06/20/05 by Jaymes Krueger
#
# Copyright (c) 2001 by cisco Systems, Inc.
# All rights reserved.
#------------------------------------------------------------------
#
# This tcl script prompts user for account number and then 
# authenticates the account number. If authenticated, the call will
# be connected. If not authenticated, call will be closed.
#
# The PIN the users enters becomes the "username" and the password
# is set by the script and remains fixed (see "set pin 123456" statement
# below).
#                      

proc init { } {

    global param

    set param(initialDigitTimeout) 10 
    set param(interruptPrompt) true
    set param(abortKey) *
    set param(terminationKey) #
}

proc act_Setup { } {

    global ani
    global dnis
    global beep
    global ctr 
    
    set ctr 0
    set beep 0

    set ani [infotag get leg_ani]
    set dnis [infotag get leg_dnis]

    leg setupack leg_incoming
    leg proceeding leg_incoming
    leg connect leg_incoming

    act_GetAccount
}

proc act_GetAccount { } {

    global param

    media play leg_incoming flash:enter_account.au

    set param(maxDigits) 20
    leg collectdigits leg_incoming param
}

proc act_GotAccount { } {

    global account
    global counter
    global ani
    global ctr
    global pin

    incr ctr

    set pin 123456
    set status [infotag get evt_status]

    if {$status == "cd_005"} {

	set account [infotag get evt_dcdigits]

	#Do authorize

	aaa authorize $account $pin  $ani "" leg_incoming

    } elseif {$status == "cd_001"} {
    
        #timeout

	set number [infotag get evt_dcdigits]

	set numberLen [ string length $number ]

	if { $numberLen == 0 } {

            if { $ctr <= 3 } {

                act_GetAccount
                fsm setstate same_state
            } else {
                call close
            }

	} else {
	    
	    #Do authorize

	    aaa authorize $account $pin $ani "" leg_incoming
        }

    } elseif {$status == "cd_002"} {

        #Aborted

        act_GetAccount
        fsm setstate same_state

    } elseif {($status == "cd_001") || 
              ($status == "cd_007") || ($status == "cd_006")} {
    
        #timeout/fail(disconnected)/invalid_no

        act_GetAccount
        fsm setstate same_state
    }
}

proc act_Authorized { } {

    global account
    global dnis

    set dnis [infotag get leg_dnis]

    set status [infotag get evt_status]

    if {$status == "ao_000"} {

        # Out going call is authorized

        puts "\t\t\t\n*** $account is authorized to call $dnis !!!\n"

        set callInfo(accountNum) $account

        leg setup $dnis callInfo leg_incoming

    } else {

        # Not authorized prompt ???

        puts "\t\t\t\n*** Sorry,$account not authorized to call $dnis !!!\n"

	call close
    }	
}
	

proc act_CallSetupDone { } {
    global beep

    set status [infotag get evt_status]

    if { $status != "ls_000"} {
	
	call close
    }
}


proc act_Cleanup { } {

    set evt_name [infotag get evt_event]
    call close
}

init 

#----------------------------------
#   State Machine
#----------------------------------

set fsm(any_state,ev_disconnected)         "act_Cleanup       same_state"
  
set fsm(CALL_INIT,ev_setup_indication)     "act_Setup         GETACCOUNT"
  
set fsm(AUTHENTICATE,ev_authorize_done)    "act_Authorized    PLACECALL"

set fsm(GETACCOUNT,ev_collectdigits_done)  "act_GotAccount    AUTHENTICATE"

set fsm(CALLACTIVE,ev_disconnected)        "act_Cleanup    CALLDISCONNECT"
set fsm(CALLDISCONNECT,ev_disconnected)    "act_Cleanup    same_state"
set fsm(CALLDISCONNECT,ev_media_done)      "act_Cleanup    same_state"
set fsm(CALLDISCONNECT,ev_disconnect_done) "act_Cleanup    same_state"
set fsm(CALLDISCONNECT,ev_leg_timer)       "act_Cleanup    same_state"

fsm define fsm CALL_INIT


# Script Approval Signature: C/7d78
